pub struct GpSurrogate { /* private fields */ }Expand description
Gaussian Process surrogate model for Bayesian optimization.
Maintains training data and the fitted model (Cholesky factor + alpha vector) for efficient prediction.
Implementations
Sourceimpl GpSurrogate
impl GpSurrogate
Sourcepub fn new(kernel: Box<dyn SurrogateKernel>, config: GpSurrogateConfig) -> Self
pub fn new(kernel: Box<dyn SurrogateKernel>, config: GpSurrogateConfig) -> Self
Create a new GP surrogate with the given kernel.
Sourcepub fn default_rbf() -> Self
pub fn default_rbf() -> Self
Create a GP surrogate with an RBF kernel and default configuration.
Sourcepub fn fit(&mut self, x: &Array2<f64>, y: &Array1<f64>) -> OptimizeResult<()>
pub fn fit(&mut self, x: &Array2<f64>, y: &Array1<f64>) -> OptimizeResult<()>
Fit the GP to training data.
Optionally optimises kernel hyperparameters via marginal likelihood maximisation.
Sourcepub fn update(
&mut self,
x_new: &Array2<f64>,
y_new: &Array1<f64>,
) -> OptimizeResult<()>
pub fn update( &mut self, x_new: &Array2<f64>, y_new: &Array1<f64>, ) -> OptimizeResult<()>
Add new observations incrementally and refit the model.
Sourcepub fn predict_mean(&self, x_test: &Array2<f64>) -> OptimizeResult<Array1<f64>>
pub fn predict_mean(&self, x_test: &Array2<f64>) -> OptimizeResult<Array1<f64>>
Predict the GP mean at test points.
Sourcepub fn predict_variance(
&self,
x_test: &Array2<f64>,
) -> OptimizeResult<Array1<f64>>
pub fn predict_variance( &self, x_test: &Array2<f64>, ) -> OptimizeResult<Array1<f64>>
Predict the GP variance at test points.
Sourcepub fn predict(
&self,
x_test: &Array2<f64>,
) -> OptimizeResult<(Array1<f64>, Array1<f64>)>
pub fn predict( &self, x_test: &Array2<f64>, ) -> OptimizeResult<(Array1<f64>, Array1<f64>)>
Predict both mean and variance at test points.
Sourcepub fn predict_single(
&self,
x: &ArrayView1<'_, f64>,
) -> OptimizeResult<(f64, f64)>
pub fn predict_single( &self, x: &ArrayView1<'_, f64>, ) -> OptimizeResult<(f64, f64)>
Predict mean and standard deviation at a single point.
Sourcepub fn log_marginal_likelihood(&self) -> OptimizeResult<f64>
pub fn log_marginal_likelihood(&self) -> OptimizeResult<f64>
Compute the log marginal likelihood of the current model.
Sourcepub fn kernel(&self) -> &dyn SurrogateKernel
pub fn kernel(&self) -> &dyn SurrogateKernel
Return a reference to the current kernel.
Sourcepub fn kernel_mut(&mut self) -> &mut dyn SurrogateKernel
pub fn kernel_mut(&mut self) -> &mut dyn SurrogateKernel
Return a mutable reference to the kernel.