pub struct RationalQuadraticKernel {
pub length_scale: f64,
pub signal_variance: f64,
pub alpha: f64,
}Expand description
Rational Quadratic kernel.
k(x, x’) = sigma^2 * (1 + ||x - x’||^2 / (2 * alpha * l^2))^(-alpha)
This can be seen as a scale mixture of RBF kernels with different length
scales. The parameter alpha controls the relative weighting of large-scale
vs small-scale variations.
Fields
length_scale: f64Length scale
signal_variance: f64Signal variance
alpha: f64Shape parameter (alpha); larger alpha => closer to RBF
Implementations