pub struct TransferBo { /* private fields */ }Expand description
Transfer Bayesian Optimizer.
Uses source-task GP surrogates to accelerate optimization on the target task.
Implementations
Sourceimpl TransferBo
impl TransferBo
Sourcepub fn new(
source_tasks: Vec<TaskObservations>,
target_bounds: Vec<(f64, f64)>,
config: TransferBoConfig,
) -> OptimizeResult<Self>
pub fn new( source_tasks: Vec<TaskObservations>, target_bounds: Vec<(f64, f64)>, config: TransferBoConfig, ) -> OptimizeResult<Self>
Create a new transfer BO instance.
Sourcepub fn optimize<F>(
&mut self,
objective: F,
n_iterations: usize,
) -> OptimizeResult<TransferBoResult>
pub fn optimize<F>( &mut self, objective: F, n_iterations: usize, ) -> OptimizeResult<TransferBoResult>
Optimize the target objective using transfer from source tasks.
n_iterations is the total number of target evaluations (excluding
any pseudo-observations from source tasks).