pub struct TransferBoConfig {
pub n_initial: usize,
pub xi: f64,
pub n_candidates: usize,
pub similarity_temperature: f64,
pub seed: Option<u64>,
pub verbose: usize,
}Expand description
Configuration for Transfer Bayesian Optimization.
Fields
n_initial: usizeNumber of initial random evaluations on the target task.
xi: f64Exploration bonus xi for EI.
n_candidates: usizeNumber of random candidates evaluated when maximising the acquisition.
similarity_temperature: f64Temperature controlling how sharply task similarity translates to weight.
seed: Option<u64>Random seed.
verbose: usizeVerbosity.