Module assignment

Module assignment 

Assignment problem solvers.

Provides the Hungarian algorithm (Kuhn-Munkres) for minimum-cost square or rectangular assignment, and a general minimum-cost bipartite matching.

Functions

hungarian_algorithm
Solve the minimum-cost assignment problem using the Hungarian algorithm.
min_cost_matching
Minimum-cost bipartite matching via the Hungarian algorithm on a sparse edge list.

Type Aliases

AssignmentResult
Result type for assignment operations.