pub struct Posynomial {
pub terms: Vec<Monomial>,
}Expand description
A posynomial: sum of monomials, each with a positive coefficient.
Fields
terms: Vec<Monomial>Non-empty list of monomials, all sharing the same variable dimension.
Implementations
Sourceimpl Posynomial
impl Posynomial
Sourcepub fn new(terms: Vec<Monomial>) -> OptimizeResult<Self>
pub fn new(terms: Vec<Monomial>) -> OptimizeResult<Self>
Construct a posynomial, validating that all monomials have the same variable dimension.
Sourcepub fn evaluate(&self, x: &[f64]) -> OptimizeResult<f64>
pub fn evaluate(&self, x: &[f64]) -> OptimizeResult<f64>
Evaluate at x.