#[non_exhaustive]pub enum BackwardMode {
FullDifferentiation,
ActiveSetOnly,
}Expand description
Mode of backward differentiation through the optimization layer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
FullDifferentiation
Differentiate through all KKT conditions (full implicit differentiation).
ActiveSetOnly
Differentiate only through active inequality constraints, treating inactive constraints as absent. Faster but approximate when constraints are near the boundary.