Module cma_es

Module cma_es 

Covariance Matrix Adaptation Evolution Strategy (CMA-ES)

CMA-ES is a stochastic, derivative-free method for numerical optimization of non-linear or non-convex continuous optimization problems. It belongs to the class of evolutionary algorithms and evolution strategies.

Key features

  • Invariant under order-preserving transformations of the fitness function
  • Robust to scaling, rotation, and translation of the search space
  • Adaptive step-size control (Cumulative Step-size Adaptation / CSA)
  • Covariance matrix adaptation via rank-1 and rank-mu updates
  • IPOP restart strategy for escaping local optima
  • Multiple boundary handling strategies

References

  • Hansen, N. (2016). The CMA Evolution Strategy: A Tutorial. arXiv:1604.00772
  • Auger, A. & Hansen, N. (2005). A Restart CMA Evolution Strategy with Increasing Population Size. CEC 2005.

Structs

CmaEsOptions
Options for CMA-ES optimization
CmaEsResult
Result of CMA-ES optimization
CmaEsState
Internal state of the CMA-ES algorithm
IpopCmaEs
IPOP-CMA-ES: CMA-ES with Increasing Population Restarts

Enums

BoundaryHandling
Boundary handling strategy for CMA-ES
RestartStrategy
Restart strategy for CMA-ES

Functions

cma_es_minimize
Convenience function to minimize using CMA-ES