pub struct DFP {
pub c: Array2<f64>,
pub n: usize,
}Expand description
DFP (Davidon–Fletcher–Powell) inverse Hessian update.
Directly updates an approximation to the inverse Hessian C ≈ H⁻¹:
Cₖ₊₁ = Cₖ - (Cₖ yₖ)(Cₖ yₖ)ᵀ / (yₖᵀ Cₖ yₖ) + sₖ sₖᵀ / (yₖᵀ sₖ)DFP is the dual of BFGS. It updates the inverse directly and can be more
efficient when inverse_multiply is called much more frequently than multiply.
Fields
c: Array2<f64>Inverse Hessian approximation C ≈ H⁻¹
n: usizeDimension
Implementations