Module lp_relaxation

Module lp_relaxation 

LP relaxation solver for use in branch-and-bound

Solves linear programs using a simplex method with big-M phase I. This is an internal solver used by the branch-and-bound and cutting plane methods.

Structs

LpRelaxationSolver
Simple LP relaxation solver
LpResult
Result from LP solve