pub struct MultigridOptimizer<F>{
pub func: F,
pub n_fine: usize,
pub n_levels: usize,
pub options: MultigridOptions,
}Expand description
Multigrid-inspired optimizer using a hierarchy of approximation levels.
The “grid levels” here represent different approximation granularities. Restriction maps a fine iterate to a coarser space; prolongation (interpolation) maps the coarse correction back to the fine space.
On each smoothing step, gradient descent is applied. The multigrid philosophy avoids slow convergence of fine-level iterations by first making progress on coarser levels.
Fields
func: FObjective function (same function evaluated at different scales)
n_fine: usizeDimensionality at finest level
n_levels: usizeNumber of multigrid levels
options: MultigridOptionsAlgorithm options
Implementations
Sourceimpl<F: Fn(&[f64]) -> f64> MultigridOptimizer<F>
impl<F: Fn(&[f64]) -> f64> MultigridOptimizer<F>
Sourcepub fn new(
func: F,
n_fine: usize,
n_levels: usize,
options: MultigridOptions,
) -> Self
pub fn new( func: F, n_fine: usize, n_levels: usize, options: MultigridOptions, ) -> Self
Create a new multigrid optimizer
Sourcepub fn minimize(&self, x0: &[f64]) -> OptimizeResult<MultilevelResult>
pub fn minimize(&self, x0: &[f64]) -> OptimizeResult<MultilevelResult>
Run the multigrid optimizer