Module hypervolume

Module hypervolume 

Hypervolume indicator computation for multi-objective optimization.

Provides exact and approximate algorithms for computing the hypervolume dominated by a Pareto front with respect to a reference point.

Algorithms

FunctionAlgorithmComplexity
hypervolume_2dSweep-line on sorted frontO(n log n)
hypervolume_3dSlice-and-sweepO(n² log n)
hypervolume_wfgWFG recursive algorithmO(n^(d-1))
hypervolume_contribution_wfgRemove-and-recomputeO(n^d)
exclusive_hypervolumePer-solution contributionsO(n^d)

References

  • While, L., Hingston, P., Barone, L., & Huband, S. (2006). A faster algorithm for calculating hypervolume. IEEE Transactions on Evolutionary Computation, 10(1), 29-38.
  • Emmerich, M., Beume, N., & Naujoks, B. (2005). An EMO algorithm using the hypervolume measure as selection criterion.
  • Bradstreet, L., While, L., & Barone, L. (2007). A fast many-objective hypervolume algorithm. ISPA, 3-10.

Functions

exclusive_hypervolume
Compute the exclusive hypervolume contribution of every solution in the front.
hypervolume_2d
Compute the hypervolume dominated by a 2-D Pareto front.
hypervolume_3d
Compute the exact 3-D hypervolume using a slice-and-sweep approach.
hypervolume_contribution_wfg
Compute the hypervolume contribution of solution idx to the total hypervolume.
hypervolume_wfg
Compute the exact hypervolume using the WFG (While-Hingston-Barone-Huband) recursive algorithm for arbitrary dimensionality.