pub struct RandomNAS {
pub n_trials: usize,
}Expand description
Random Neural Architecture Search.
Samples n_trials architectures uniformly at random from the search
space and returns the one with the highest fitness score.
Fields
n_trials: usizeNumber of random architectures to evaluate
Implementations
Sourceimpl RandomNAS
impl RandomNAS
Sourcepub fn search<F: ArchFitness>(
&self,
space: &SearchSpace,
fitness: &F,
seed: u64,
) -> Result<NASResult, OptimizeError>
pub fn search<F: ArchFitness>( &self, space: &SearchSpace, fitness: &F, seed: u64, ) -> Result<NASResult, OptimizeError>
Run random search over the given space using fitness.
Arguments
space: The architecture search space to sample from.fitness: Fitness evaluator (higher = better).seed: Random seed for reproducibility.