pub enum UncertaintySet {
Box {
delta: Array1<f64>,
},
Ellipsoidal {
center: Array1<f64>,
covariance: Array2<f64>,
radius: f64,
},
Polyhedral {
a_matrix: Array2<f64>,
b_vector: Array1<f64>,
},
BudgetedUncertainty {
delta: Array1<f64>,
budget: f64,
},
}Expand description
Describes the geometry of an uncertainty set for robust optimization.
Variants
Box
Axis-aligned box: ‖ξ‖∞ ≤ δ, i.e. |ξ_i| ≤ delta_i for each component.
Ellipsoidal
Ellipsoidal set: {ξ : ξᵀ Σ⁻¹ ξ ≤ ρ²} where Σ is a positive-definite covariance matrix.
Fields
Polyhedral
Polyhedral set: {ξ : A ξ ≤ b}.
Fields
BudgetedUncertainty
Bertsimas-Sim budgeted uncertainty: at most Γ of the n parameters can deviate by their full radius δ_i.