pub struct MinimaxProblem {
pub funcs: Vec<Box<dyn Fn(&ArrayView1<'_, f64>) -> f64 + Send + Sync>>,
}Expand description
A minimax problem: minimize the maximum over k functions.
Represents:
min_x max_{i=0..k-1} f_i(x)Example
use scirs2_optimize::robust::minimax::MinimaxProblem;
use scirs2_core::ndarray::ArrayView1;
// max(f0, f1) where f0(x)=x[0]+1, f1(x)=-x[0]+2
let problem = MinimaxProblem::new(vec![
Box::new(|x: &ArrayView1<f64>| x[0] + 1.0),
Box::new(|x: &ArrayView1<f64>| -x[0] + 2.0),
]);Fields
funcs: Vec<Box<dyn Fn(&ArrayView1<'_, f64>) -> f64 + Send + Sync>>The functions f_i(x) being maximized.
Implementations
Sourceimpl MinimaxProblem
impl MinimaxProblem
Sourcepub fn new(
funcs: Vec<Box<dyn Fn(&ArrayView1<'_, f64>) -> f64 + Send + Sync>>,
) -> Self
pub fn new( funcs: Vec<Box<dyn Fn(&ArrayView1<'_, f64>) -> f64 + Send + Sync>>, ) -> Self
Create a new minimax problem from a collection of functions.
Sourcepub fn eval_max(&self, x: &ArrayView1<'_, f64>) -> f64
pub fn eval_max(&self, x: &ArrayView1<'_, f64>) -> f64
Evaluate max_i f_i(x).
Sourcepub fn eval_all(&self, x: &ArrayView1<'_, f64>) -> Vec<f64>
pub fn eval_all(&self, x: &ArrayView1<'_, f64>) -> Vec<f64>
Evaluate all function values f_i(x).
Sourcepub fn argmax(&self, x: &ArrayView1<'_, f64>) -> usize
pub fn argmax(&self, x: &ArrayView1<'_, f64>) -> usize
Return the index of the maximizing function at x.