pub struct AdaGradOptimizer {
pub lr: f64,
pub eps: f64,
pub accum: Vec<f64>,
}Expand description
AdaGrad optimizer.
Adapts the learning rate for each parameter by accumulating squared gradients. Parameters that receive large, frequent gradients see smaller effective learning rates.
Update rule
G_t = G_{t-1} + g_t ⊙ g_t
θ_t = θ_{t-1} - α / (√G_t + ε) ⊙ g_tReference: Duchi et al. (2011).
Fields
lr: f64Global learning rate
eps: f64Numerical stability constant
accum: Vec<f64>Accumulated squared gradients
Implementations
Sourceimpl AdaGradOptimizer
impl AdaGradOptimizer