Assignment problem solvers.
Provides the Hungarian algorithm (Kuhn-Munkres) for minimum-cost square or rectangular assignment, and a general minimum-cost bipartite matching.
Functions
- hungarian_
algorithm - Solve the minimum-cost assignment problem using the Hungarian algorithm.
- min_
cost_ matching - Minimum-cost bipartite matching via the Hungarian algorithm on a sparse edge list.
Type Aliases
- Assignment
Result - Result type for assignment operations.