High-dimensional optimization methods
This module provides optimization algorithms specifically designed for high-dimensional problems where standard methods may be too expensive.
Modules
coordinate_descent: Coordinate descent variants (cyclic, randomized, greedy, proximal, block)kaczmarz: Kaczmarz iteration for solving linear systems Ax = bsketched_gd: Sketched gradient descent with dimensionality reduction
Re-exports
pub use coordinate_descent::BlockCoordinateDescent;pub use coordinate_descent::CoordinateDescentConfig;pub use coordinate_descent::CoordinateDescentResult;pub use coordinate_descent::CoordinateDescentSolver;pub use coordinate_descent::CoordinateSelectionStrategy;pub use coordinate_descent::ProximalCoordinateDescent;pub use coordinate_descent::RegularizationType;pub use kaczmarz::BlockKaczmarz;pub use kaczmarz::ExtendedKaczmarz;pub use kaczmarz::KaczmarzConfig;pub use kaczmarz::KaczmarzResult;pub use kaczmarz::KaczmarzSolver;pub use kaczmarz::KaczmarzVariant;pub use sketched_gd::SketchType;pub use sketched_gd::SketchedGdConfig;pub use sketched_gd::SketchedGdResult;pub use sketched_gd::SketchedGradientDescent;
Modules
- coordinate_
descent - Coordinate Descent optimization methods
- kaczmarz
- Kaczmarz method for solving linear systems Ax = b
- sketched_
gd - Sketched Gradient Descent