pub fn hypervolume(
solutions: &[MultiObjectiveSolution],
reference_point: &[f64],
) -> f64Expand description
Calculate the hypervolume indicator for a set of solutions.
For 2D problems, uses an exact O(N log N) sweep-line algorithm. For 3D+ problems, uses the WFG (Walking Fish Group) exact algorithm.
All solutions must have objective values strictly dominated by reference_point
to contribute to the hypervolume.