Hypervolume indicator computation for multi-objective optimization.
Provides exact and approximate algorithms for computing the hypervolume dominated by a Pareto front with respect to a reference point.
Algorithms
| Function | Algorithm | Complexity |
|---|---|---|
hypervolume_2d | Sweep-line on sorted front | O(n log n) |
hypervolume_3d | Slice-and-sweep | O(n² log n) |
hypervolume_wfg | WFG recursive algorithm | O(n^(d-1)) |
hypervolume_contribution_wfg | Remove-and-recompute | O(n^d) |
exclusive_hypervolume | Per-solution contributions | O(n^d) |
References
- While, L., Hingston, P., Barone, L., & Huband, S. (2006). A faster algorithm for calculating hypervolume. IEEE Transactions on Evolutionary Computation, 10(1), 29-38.
- Emmerich, M., Beume, N., & Naujoks, B. (2005). An EMO algorithm using the hypervolume measure as selection criterion.
- Bradstreet, L., While, L., & Barone, L. (2007). A fast many-objective hypervolume algorithm. ISPA, 3-10.
Functions
- exclusive_
hypervolume - Compute the exclusive hypervolume contribution of every solution in the front.
- hypervolume_
2d - Compute the hypervolume dominated by a 2-D Pareto front.
- hypervolume_
3d - Compute the exact 3-D hypervolume using a slice-and-sweep approach.
- hypervolume_
contribution_ wfg - Compute the hypervolume contribution of solution
idxto the total hypervolume. - hypervolume_
wfg - Compute the exact hypervolume using the WFG (While-Hingston-Barone-Huband) recursive algorithm for arbitrary dimensionality.